class Links:
    """Object that will hold link data"""
    def __init__(self, text, href, seo):
        self.text = text
        self.href = href
        self.seo = seo

    def __repr__(self):
        return "<Links text=%r, href=%r>" % (self.text, self.href)

    def __str__(self):
        return str(self.__repr__)



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

setup(
    name='linkGrabber',
    version='0.1.6',
    author='Eric Bower',
    author_email='neurosnap@gmail.com',
    packages=['linkGrabber', 'linkGrabber.tests'],
    scripts=[],
    url='http://pypi.python.org/pypi/linkGrabber',
    license='LICENSE.rst',
    description='Scrape links from a single web site',
    long_description=open('README.rst').read(),
    install_requires=[
        "BeautifulSoup"
    ],
)
